"""Renamed DiagramGeneric table

Peek Plugin Database Migration Script

Revision ID: bac1e4f7a3d9
Revises: 1f288982a4e2
Create Date: 2019-06-13 17:05:23.123698

"""

# revision identifiers, used by Alembic.
revision = "bac1e4f7a3d9"
down_revision = "1f288982a4e2"
branch_labels = None
depends_on = None

from alembic import op


def upgrade():
    renameToDocDbSql = """
            DO $$
            BEGIN
                IF EXISTS(
                    SELECT table_schema
                      FROM information_schema.tables
                      WHERE table_schema = 'pl_docdb_generic_menu'
                        AND table_name = 'GenericDiagramMenu'
                  )
                THEN
                  EXECUTE ' ALTER TABLE pl_docdb_generic_menu."GenericDiagramMenu" 
                            RENAME TO "Menu" ';
                END IF;
            END
            $$;
        """
    op.execute(renameToDocDbSql)


def downgrade():
    op.rename_table(
        "DiagramGenericMenu", "GenericDiagramMenu", schema="pl_diagram_generic_menu"
    )



from sqlalchemy import Column
from sqlalchemy import Integer, String
from vortex.Tuple import Tuple, addTupleType

from peek_plugin_docdb_generic_menu._private.PluginNames import (
    docDbGenericMenuTuplePrefix,
)
from peek_plugin_docdb_generic_menu._private.storage.DeclarativeBase import (
    DeclarativeBase,
)


@addTupleType
class DocDbGenericMenuTuple(Tuple, DeclarativeBase):
    __tupleType__ = docDbGenericMenuTuplePrefix + "DocDbGenericMenuTuple"
    __tablename__ = "Menu"

    id = Column(Integer, primary_key=True, autoincrement=True)
    modelSetKey = Column(String)
    coordSetKey = Column(String)
    faIcon = Column(String)
    title = Column(String)
    tooltip = Column(String)
    url = Column(String, nullable=False)
    showCondition = Column(String, nullable=True)



from sqlalchemy.ext.declarative import declarative_base

from sqlalchemy.schema import MetaData

metadata = MetaData(schema="pl_docdb_generic_menu")
DeclarativeBase = declarative_base(metadata=metadata)


def loadStorageTuples():
    """Load Storage Tables

    This method should be called from the "load()" method of the agent, server, worker
    and client entry hook classes.

    This will register the ORM classes as tuples, allowing them to be serialised and
    deserialized by the vortex.

    """
    from . import DocDbGenericMenuTuple

    DocDbGenericMenuTuple.__unused = False

    from . import Setting

    Setting.__unused = False



docDbGenericMenuFilt = {"plugin": "peek_plugin_docdb_generic_menu"}
docDbGenericMenuTuplePrefix = "peek_plugin_docdb_generic_menu."
docDbGenericMenuObservableName = "peek_plugin_docdb_generic_menu"
docDbGenericMenuActionProcessorName = "peek_plugin_docdb_generic_menu"
docDbGenericMenuTupleOfflineServiceName = "peek_plugin_docdb_generic_menu"



"""added condition

Peek Plugin Database Migration Script

Revision ID: 1ac6c325c7e5
Revises: 9e52cf449784
Create Date: 2019-08-05 11:48:30.808843

"""

# revision identifiers, used by Alembic.
revision = "1ac6c325c7e5"
down_revision = "9e52cf449784"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "Menu",
        sa.Column("showCondition", sa.String(), nullable=True),
        schema="pl_docdb_generic_menu",
    )
    op.add_column(
        "Menu",
        sa.Column("tooltip", sa.String(), nullable=True),
        schema="pl_docdb_generic_menu",
    )
    op.alter_column(
        "Menu",
        "title",
        existing_type=sa.VARCHAR(),
        nullable=True,
        schema="pl_docdb_generic_menu",
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column(
        "Menu",
        "title",
        existing_type=sa.VARCHAR(),
        nullable=False,
        schema="pl_docdb_generic_menu",
    )
    op.drop_column("Menu", "tooltip", schema="pl_docdb_generic_menu")
    op.drop_column("Menu", "showCondition", schema="pl_docdb_generic_menu")
    # ### end Alembic commands ###
